# APP_NAME_PLACEHOLDER

My new awesome homebrew application for the Nintendo Switch, created with [PyNX](https://github.com/nx-python/PyNX).

[![generated_by nxstart](https://img.shields.io/badge/generated_by-nxstart-blue.svg)](https://github.com/roedesh/nxstart)

## Features

...

## Getting Started

Download the [latest release of PyNX](https://github.com/nx-python/PyNX/releases) 
and copy the `switch` folder to your SD card. PyNX will appear on your homebrew menu.

### Running the app

Place your `main.py` next to `PyNX.nro`, and it will be executed as soon as you launch PyNX from the Homebrew Menu.

## Author

APP_AUTHOR_PLACEHOLDER